@@ -1,5 +1,7 @@
+from .argparse import ArgParse
 from .testing import FlaskTestingExt
 
 __all__ = [
+    "ArgParse",
     "FlaskTestingExt",
 ]
